@@ -1,4 +1,4 @@
-from .pacmap import PaCMAP, sample_neighbors_pair
+from .pacmap import PaCMAP, sample_neighbors_pair, LocalMAP
 
 from importlib.metadata import version, PackageNotFoundError
 
@@ -7,4 +7,4 @@ try:
 except PackageNotFoundError:
     __version__ = "unknown"
 
-__all__ = ["PaCMAP", "sample_neighbors_pair"]
+__all__ = ["PaCMAP", "sample_neighbors_pair", "LocalMAP"]
